Crate graphcore

Crate graphcore 

GQLite logo graphcore

GraphCore is part of the GQLite project project, it provides base type for representing values, nodes and edges in a property graph.

Macros

array
Convenient macro for creating Array.
labels
Convenient macro to create a vector of label, from &str.
table
Convenient macro for creating tables.
value_map
Convenient macro for creating ValueMap.

Structs

Edge
Directed edge of the graph.
Key
Uuid of a graph element (node, edge…).
Node
Represent a Node in the graph
SinglePath
SinglePath in the graph. A SinglePath contains an edge, source and destination.
Table
Table of values
TimeStamp
Represent a timestamp
ValueMap
A map of values.

Enums

Error
Represent errors.
FromValueResult
Used to try conversion and return value instead of error
Value
Represent a value in a properties for a Node or an Edge.

Traits

ValueTryIntoRef
Trait to return a reference to the underlying type