graphcore
GraphCore is part of the GQLite project project, it provides base type for representing values, nodes and edges in a property graph.
Macros
- array
- Convenient macro for creating Array.
- labels
- Convenient macro to create a vector of label, from &str.
- table
- Convenient macro for creating tables.
- value_
map - Convenient macro for creating ValueMap.
Structs
- Edge
- Directed edge of the graph.
- Key
- Uuid of a graph element (node, edge…).
- Node
- Represent a Node in the graph
- Single
Path - SinglePath in the graph. A SinglePath contains an edge, source and destination.
- Table
- Table of values
- Time
Stamp - Represent a timestamp
- Value
Map - A map of values.
Enums
- Error
- Represent errors.
- From
Value Result - Used to try conversion and return value instead of error
- Value
- Represent a value in a properties for a Node or an Edge.
Traits
- Value
TryInto Ref - Trait to return a reference to the underlying type